#!/bin/bash

set -eu

BASEDIR=~/.cygwin-toolchain-switcher

if [[ -d $BASEDIR ]] ; then
	echo "WARNING: Directory ${BASEDIR} already exists" >&2
	read -p "Remove existing directory? (y/n) " shouldremove
	if [[ $shouldremove == "y" ]] ; then
		rm -rf "${BASEDIR}"
	else
		echo "FATAL: Directory ${BASEDIR} already exists, not removing" >&2
		exit 1
	fi
fi

mkdir "${BASEDIR}"

list_toolchains() {
	ls /usr/bin | grep '\-gcc.exe$' | sed 's/-gcc.exe//'
}

list_toolchains | while read -r toolchain ; do

	#1. Header
	echo "Building links for ${toolchain}..."

	#2. Symlinks
	tcdir="${BASEDIR}/toolchain-${toolchain}"
	mkdir "${tcdir}"
	
	ls /usr/bin | grep "^${toolchain}" | while read -r binname ; do
	
		shortname="$(echo "${binname}" | sed "s/${toolchain}-//")"
		shortname2="$(echo "${shortname}" | sed 's/.exe//')"
		
		# To create windows symlinks instead of cygwin symlinks, need to
		#  export CYGWIN="winsymlinks:nativestrict" and also run this
		#  script as administrator
		
		ln -s "/usr/bin/${binname}" "${tcdir}/${shortname2}"
		ln -s "/usr/bin/${binname}" "${tcdir}/${shortname}"
		
	done
	
	#3. Helper script
	helper="${BASEDIR}/use-toolchain-${toolchain}.sh"
	cat > "${helper}" <<EOD
#!/bin/bash
export PATH="${tcdir}:${PATH}"
EOD
	chmod +x "${helper}"
	
done
